summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--libglusterfs/src/graph.c2
-rw-r--r--xlators/features/cloudsync/src/cloudsync-plugins/src/cvlt/src/libcvlt.c4
2 files changed, 3 insertions, 3 deletions
diff --git a/libglusterfs/src/graph.c b/libglusterfs/src/graph.c
index 913f57804cc..679d8a2d25d 100644
--- a/libglusterfs/src/graph.c
+++ b/libglusterfs/src/graph.c
@@ -1378,7 +1378,7 @@ glusterfs_graph_cleanup(void *arg)
ret = pthread_mutex_lock(&graph->mutex);
if (ret != 0) {
gf_msg("glusterfs", GF_LOG_ERROR, EAGAIN, LG_MSG_GRAPH_CLEANUP_FAILED,
- "Failed to aquire a lock");
+ "Failed to acquire a lock");
goto out;
}
/* check and wait for CHILD_DOWN for top xlator*/
diff --git a/xlators/features/cloudsync/src/cloudsync-plugins/src/cvlt/src/libcvlt.c b/xlators/features/cloudsync/src/cloudsync-plugins/src/cvlt/src/libcvlt.c
index 5243c8bd492..5b7272bb448 100644
--- a/xlators/features/cloudsync/src/cloudsync-plugins/src/cvlt/src/libcvlt.c
+++ b/xlators/features/cloudsync/src/cloudsync-plugins/src/cvlt/src/libcvlt.c
@@ -625,7 +625,7 @@ cvlt_download(call_frame_t *frame, void *config)
}
/*
* We need t perform in-place restore of the file from data managment
* store to gusterfs volume.
*/
op_ret = cvlt_init_gluster_store_info(locxattr, &dest_storeinfo);
@@ -653,7 +653,7 @@ cvlt_download(call_frame_t *frame, void *config)
cvlt_download_complete, req);
if (op_ret < 0) {
gf_msg(plugin, GF_LOG_ERROR, 0, CVLT_RESTORE_FAILED,
- " failed to restore file gfid=%s from data managment store",
+ " failed to restore file gfid=%s from data management store",
uuid_utoa(locxattr->gfid));
goto err;
}
@@ -625,7 +625,7 @@ cvlt_download(call_frame_t *frame, void *config)
}
/*
- * We need t perform in-place restore of the file from data managment
+ * We need to perform in-place restore of the file from data management
* store to gusterfs volume.
*/